==> kibana-7.6.2p0.tgz: kibana/src/plugins/data/public/query/filter_manager/test_helpers/get_filters_array.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getFiltersArray = getFiltersArray;

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
function getFiltersArray() {
  return [{
    query: {
      match: {
        extension: {
          query: 'jpg',
          type: 'phrase'
        }
      }
    },
    meta: {
      index: 'logstash-*',
      negate: false,
      disabled: false,
      alias: null
    }
  }, {
    query: {
      match: {
        '@tags': {
          query: 'info',
          type: 'phrase'
        }
      }
    },
    meta: {
      index: 'logstash-*',
      negate: false,
      disabled: false,
      alias: null
    }
  }, {
    query: {
      match: {
        _type: {
          query: 'nginx',
          type: 'phrase'
        }
      }
    },
    meta: {
      index: 'logstash-*',
      negate: false,
      disabled: false,
      alias: null
    }
  }];
}

==> kibana-7.9.1.tgz: kibana/src/plugins/data/public/query/filter_manager/test_helpers/get_filters_array.js <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
export function getFiltersArray() {
  return [{
    query: {
      match: {
        extension: {
          query: 'jpg',
          type: 'phrase'
        }
      }
    },
    meta: {
      index: 'logstash-*',
      negate: false,
      disabled: false,
      alias: null
    }
  }, {
    query: {
      match: {
        '@tags': {
          query: 'info',
          type: 'phrase'
        }
      }
    },
    meta: {
      index: 'logstash-*',
      negate: false,
      disabled: false,
      alias: null
    }
  }, {
    query: {
      match: {
        _type: {
          query: 'nginx',
          type: 'phrase'
        }
      }
    },
    meta: {
      index: 'logstash-*',
      negate: false,
      disabled: false,
      alias: null
    }
  }];
}
